tonalanalysistools.TonalAnalysisAgent
=====================================

.. abjad-lineage:: abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent

.. autoclass:: abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.analyze_chords
      ~abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.analyze_incomplete_chords
      ~abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.analyze_incomplete_tonal_functions
      ~abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.analyze_neighbor_notes
      ~abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.analyze_passing_tones
      ~abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.analyze_tonal_functions
      ~abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.are_scalar_notes
      ~abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.are_stepwise_ascending_notes
      ~abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.are_stepwise_descending_notes
      ~abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.are_stepwise_notes
      ~abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.client
      ~abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.__eq__
      ~abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.__format__
      ~abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.__ne__
      ~abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.client
   :noindex:

Methods
-------

.. automethod:: abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.analyze_chords
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.analyze_incomplete_chords
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.analyze_incomplete_tonal_functions
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.analyze_neighbor_notes
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.analyze_passing_tones
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.analyze_tonal_functions
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.are_scalar_notes
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.are_stepwise_ascending_notes
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.are_stepwise_descending_notes
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.are_stepwise_notes
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.__format__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.TonalAnalysisAgent.TonalAnalysisAgent.__repr__
   :noindex:
